package envoy.event;

import envoy.data.User;

/**
 * Project: <strong>envoy-common</strong><br>
 * File: <strong>ContactOperation.java</strong><br>
 * Created: <strong>05.02.2020</strong><br>
 * 
 * @author Maximilian K&auml;fer
 * @since Envoy Common v0.2-alpha
 */
public class ContactOperation implements Event<User> {

	public enum Operation {
		ADD, REMOVE;
	}

	private final User		contact;
	private final Operation	operationType;

	private static final long serialVersionUID = -1166652868189511553L;

	/**
	 * Initializes a {@link ContacsOperation}.
	 * 
	 * @param operationType the {@link Operation} which should be executed on the
	 *                      {@link contact}.
	 * @since Envoy Common v0.2-alpha
	 */
	public ContactOperation(User contact, Operation operationType) {
		this.contact		= contact;
		this.operationType	= operationType;
	}

	/**
	 * @return the {@link User}, which should be added/removed from the contacts
	 *         list.
	 * @since Envoy Common v0.2-alpha
	 */
	@Override
	public User get() { return contact; }

	/**
	 * @return the {@link Operation}, which should be executed with the contact,
	 *         this event corresponds with.
	 * @since Envoy Common v0.2-alpha
	 */
	public Operation getOperationType() { return operationType; }
}
